package com.caimei365.order.mapper;

import com.caimei365.order.model.po.BalanceRecordPo;
import com.caimei365.order.model.po.OrderPo;
import com.caimei365.order.model.po.OrderProductPo;
import com.caimei365.order.model.vo.*;
import org.apache.ibatis.annotations.Mapper;
import org.apache.ibatis.annotations.Param;

import java.util.List;

/**
 * Description
 *
 * @author : Charles
 * @date : 2021/7/19
 */
@Mapper
public interface OrderClubMapper {
    /**
     * 判断订单是否存在
     * @param orderId 订单Id
     */
    int countMainOrderByOrderId(Integer orderId);
    /**
     * 根据订单Id查询订单
     * @param orderId 订单Id
     */
    OrderPo getMainOrderByOrderId(Integer orderId);
    /**
     * 根据订单Id查询订单商品列表
     * @param orderId 订单Id
     */
    List<OrderProductPo> getOrderProductList(Integer orderId);
    /**
     * 设置二手仪器已售
     * @param productId 商品Id
     */
    void updateSecondStatus(Integer productId, Integer sold);
    /**
     * 根据用户Id更新用户余额
     * @param userId 用户Id
     */
    void updateUserMoneyByUserId(double userMoney, Integer userId);
    /**
     * 根据用户Id更新用户可用余额
     * @param userId 用户Id
     */
    void updateAbleUserMoneyByUserId(double ableUserMoney, Integer userId);
    /**
     * 更新订单状态
     * @param order 主订单
     */
    void updateOrderStatus(OrderPo order);
    /**
     * 取消 余额收支记录
     * @param balanceRecord
     */
    void cancelBalanceRecord(BalanceRecordPo balanceRecord);
    /**
     * 取消 订单
     * @param order
     */
    void cancelMainOrder(OrderPo order);
    /**
     * 逻辑删除主订单
     * @param order
     */
    void deleteMainOrder(OrderPo order);
    /**
     * 逻辑删除子订单
     * @param shopOrderIds 子订单Ids
     */
    void deleteShopOrder(@Param("shopOrderIds") List<String> shopOrderIds);
    /**
     * 获取收款记录Id列表
     * @param orderId 订单Id
     */
    List<String> getOrderReceiptIds(Integer orderId);
    /**
     * 逻辑删除订单与收款记录关系表
     * @param orderId 订单Id
     */
    void deleteOrderReceiptRelation(Integer orderId);
    /**
     * 逻辑删除收款记录表
     * @param receiptIds 收款记录Ids
     */
    void deleteDiscernReceipt(@Param("receiptIds") List<String> receiptIds);
    /**
     * 获取付款记录Id列表
     * @param shopOrderIds 子订单Ids
     */
    List<String> getPayShopIds(@Param("shopOrderIds") List<String> shopOrderIds);
    /**
     * 逻辑删除订单与付款记录关系表
     * @param shopOrderIds 子订单Ids
     */
    void deletePayShopRecord(@Param("shopOrderIds") List<String> shopOrderIds);
    /**
     * 逻辑删除付款记录表
     * @param payIds 付款记录Ids
     */
    void deletePayShop(@Param("payIds") List<String> payIds);
    /**
     * 更新物流状态
     * @param orderId 订单Id
     */
    void updateLogisticsBatch(Integer orderId);
    /**
     * 机构订单列表
     * @param userId     用户Id
     * @param orderState 1:待确认,2:待付款,3:待发货,4:已发货,5:退货款
     * @param orderNo    订单编号
     * @param beginTime  开始时间
     * @param endTime    截止时间
     */
    List<OrderVo> getOrderList(Integer userId, Integer orderState, String orderNo, String beginTime, String endTime);
    /**
     * 根据关键词搜索订单
     * @param searchWord 关键词
     * @param userId     用户Id
     */
    List<OrderVo> getOrderListByKeyword(String searchWord, Integer userId);
    /**
     * 查询订单发货次数
     * @param orderId 订单Id
     */
    int countLogisticsBatch(Integer orderId);
    /**
     * 根据子订单Id查询子订单列表
     * @param shopOrderIds 子订单Ids
     */
    List<ShopOrderVo> getShopOrderList(@Param("shopOrderIds") List<String> shopOrderIds);
    /**
     * 根据Id获取订单促销
     * @param orderPromotionsId 订单促销Id
     */
    PromotionsVo getOrderPromotionsById(Integer orderPromotionsId);
    /**
     * 获取子订单订单商品
     * @param shopOrderId 子订单Id
     */
    List<OrderProductVo> getShopOrderProduct(Integer shopOrderId);
    /**
     * 支付记录(收款记录)
     * @param orderId 订单Id
     */
    List<DiscernReceiptVo> getDiscernReceipt(Integer orderId);
    /**
     * 获取返佣款
     * @param shopOrderId 子订单Id
     */
    Double getRebateAmountByShopOrder(Integer shopOrderId);
    /**
     * 是否可以走线上支付
     * @param orderId 订单Id
     */
    int countOfflinePayment(Integer orderId);
    /**
     * 付供应商费用列表
     * @param orderId 订单Id
     */
    List<Double> getShouldPayShopAmountList(Integer orderId);
    /**
     * 查询关键字历史记录是否存在
     * @param searchWord 关键字
     */
    Integer getSearchHistoryIdByWord(String searchWord);
    /**
     * 更新搜索关键词历史记录
     * @param historyRecord SearchHistoryVo
     */
    void updateSearchHistory(SearchHistoryVo historyRecord);
    /**
     * 新增搜索关键词历史记录
     * @param historyRecord SearchHistoryVo
     */
    void insertSearchHistory(SearchHistoryVo historyRecord);
    /**
     * 统计搜索关键词数量
     * @param userId 用户Id
     */
    int countSearchHistory(Integer userId);
    /**
     * 只保留10条的搜索关键词历史记录
     * @param userId 用户Id
     */
    void deleteSearchHistoryLimit(Integer userId);
    /**
     * 根据用户Id查找订单搜索历史记录
     * @param userId 用户Id
     */
    List<SearchHistoryVo> getOrderSearchHistory(Integer userId);
    /**
     * 根据用户Id删除订单搜索历史记录
     * @param userId 用户Id
     */
    void deleteOrderSearchHistory(Integer userId);
    /**
     * 已退货数量
     * @param shopOrderId 子订单Id
     * @param productId   商品Id
     */
    Integer countReturnedNum(Integer shopOrderId, Integer productId);
    /**
     * 已取消发货数量
     * @param shopOrderId 子订单Id
     * @param productId   商品Id
     */
    Integer countActualCancelNum(Integer shopOrderId, Integer productId);
    /**
     * 退款记录
     * @param orderId 订单Id
     */
    List<ReturnedPurchaseVo> getReturnedPurchaseList(Integer orderId);
    /**
     * 售后条款
     * @param clauseId 条款Id
     */
    ClauseVo getClauseById(Integer clauseId);
    /**
     * 收货地址
     * @param orderId 订单Id
     */
    OrderUserinfoVo getOrderUserinfo(Integer orderId);
    /**
     * 获取物流批次列表
     * @param orderId 订单Id
     */
    List<LogisticsBatchVo> getLogisticsBatchList(Integer orderId);
    /**
     * 获取物流批次子订单Id列表
     * @param orderId 订单Id
     * @param id 物流批次Id
     */
    List<String> getBatchShopOrderIds(Integer orderId, Integer id);
    /**
     * 获取发货物流记录
     * @param shopOrderId      子订单Id
     * @param logisticsBatchId 物流批次Id
     */
    List<LogisticsRecordVo> getLogisticsRecord(Integer shopOrderId, Integer logisticsBatchId);
    /**
     * 获取物流信息
     * @param logisticsBatchId 物流批次Id
     */
    List<LogisticsInformationVo> getLogisticsInfoList(Integer logisticsBatchId);
    /**
     * 获取数据库已有分享码
     * @param orderId 订单Id
     */
    OrderShareCodeVo getOrderCodeById(Integer orderId);
    /**
     * 删除分享码使用记录
     * @param orderId 订单Id
     */
    void deleteOrderShareCodeRecord(Integer orderId);
    /**
     * 更新数据库的分享码
     */
    void updateOrderShareCode(OrderShareCodeVo orderShareCode);
    /**
     * 新增数据库的分享码
     */
    void insertOrderShareCode(OrderShareCodeVo orderShareCode);
    /**
     * 根据openId统计数据库内是否有有效分享码
     */
    int countShareCodeRecord(Integer orderId, String openId);
    /**
     * 保存分享码使用记录
     */
    void insertOrderShareCodeRecord(OrderShareCodeRecordVo codeRecord);
    /**
     * 更具订单Id获取订单商品列表
     * @param orderId 订单Id
     */
    List<OrderProductVo> getOrderProductByOrderId(Integer orderId);
}
