package com.caimei365.order.service;

import com.caimei365.order.model.ResponseJson;
import com.caimei365.order.model.dto.CartDto;

import java.util.Map;

/**
 * Description
 *
 * @author : Charles
 * @date : 2021/6/25
 */
public interface CartClubService {

    /**
     * 购物车列表详细数据
     * @param userId 用户Id
     */
    ResponseJson<Map<String, Object>> getShoppingCartList(Integer userId);

    /**
     * 网站顶部购物车数据
     * @param userId 用户Id
     */
    ResponseJson<Map<String, Object>> getShoppingCartHead(Integer userId);

    /**
     * 添加购物车
     *
     * @param cartDto {
     *                userId       用户ID
     *                productId    商品id
     *                productCount 商品数量
     * }
     */
    ResponseJson<Integer> addShoppingCart(CartDto cartDto);

    /**
     * 更新购物车
     *
     * @param cartDto {
     *                userId       用户ID
     *                productId    商品id
     *                productCount 商品数量
     * }
     */
    ResponseJson<Integer> updateShoppingCart(CartDto cartDto);

    /**
     * 删除购物车
     *
     * @param cartDto {
     *                userId       用户ID
     *                productIds   商品ids,逗号隔开
     * }
     */
    ResponseJson<Integer> deleteShoppingCart(CartDto cartDto);

    /**
     * 购物车结算
     *
     * @param  userId       用户ID
     * @param  productIds   商品ids,逗号隔开
     */
    ResponseJson<Map<String, Object>> settlementShoppingCart(Integer userId, String productIds);

    /**
     * 立即购买
     *
     * @param cartDto {
     *                userId       用户ID
     *                productId    商品id
     *                productCount 商品数量
     * }
     */
    ResponseJson<Map<String, Object>> buyNowProduct(CartDto cartDto);

    /**
     * 获取结算商品运费
     * @param  userId       用户ID
     * @param  productIds   商品ids,逗号隔开
     * @param townId        地区Id
     */
    ResponseJson<Map<String, Object>> getProductsPostage(Integer userId, String productIds, Integer townId);
}
